require 'optparse'
require 'publicity/host_is_osx'
require 'publicity/prompt'
require 'publicity/version'

module Publicity
  # Kicks off the parsing process by parsing command-line arguments and calling
  # the method that parses each input file.
  class Exec
    # @param args [Array<String>] All command-line arguments
    def initialize(args)
      @args = args
      @options = {}
    end

    # Parses the command-line arguments and begins parsing the files.
    #
    # @see #parse
    def parse!
      parse
      exit 0
    end

    # Parses the command-line arguments and begins parsing the files.
    #
    # @see #parse!
    def parse
      @opts = OptionParser.new(&method(:set_opts))
      @opts.parse!(@args)

      process_result
    end

    # Takes the command-line arguments and parses them for optparse.
    #
    # @param opts [OptionParser]
    def set_opts(opts)
      opts.banner = <<EOS
publicity v#{Publicity::VERSION}

Description:

TODO

Usage (from within a .git repository):

  publicity [options]

Options:
EOS

      opts.on_tail( '-h', '--help', 'Display this screen' ) do
        puts opts
        exit
      end
    end

    # Kickstarts the script prompt
    def process_result
      Publicity::Main.new
    end
  end
end
